@@ -14,7 +14,7 @@ Usage::
 import sys
 from typing import IO, Any, Dict, List, Union
 
-from .literals import DecimalReturnType, TypeHint
+from .literals import DecimalReturnTypeType, TypeHintType
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -162,7 +162,7 @@ ResultSetMetadataTypeDef = TypedDict(
 ResultSetOptionsTypeDef = TypedDict(
     "ResultSetOptionsTypeDef",
     {
-        "decimalReturnType": DecimalReturnType,
+        "decimalReturnType": DecimalReturnTypeType,
     },
     total=False,
 )
@@ -179,7 +179,7 @@ SqlParameterTypeDef = TypedDict(
     "SqlParameterTypeDef",
     {
         "name": str,
-        "typeHint": TypeHint,
+        "typeHint": TypeHintType,
         "value": "FieldTypeDef",
     },
     total=False,
@@ -197,7 +197,7 @@ SqlStatementResultTypeDef = TypedDict(
 StructValueTypeDef = TypedDict(
     "StructValueTypeDef",
     {
-        "attributes": List[Dict[str, Any]],
+        "attributes": List["ValueTypeDef"],
     },
     total=False,
 )
